==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/profiles_import/translations/profiles_import_szl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="szl" version="2.0">
<context>
    <name>ImportProfileWindow</name>
    <message>
        <source>Import external Kadu 0.6.5 profile</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select profile path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select profile path:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select imported account identity:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;Identity not selected&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;Selected directory does not contain kadu.conf.xml file&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This directory is not a Kadu profile directory.
File kadu.conf.xml not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Profile successfully imported!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to import profile: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImportProfilesWindow</name>
    <message>
        <source>&lt;p&gt;Current version of Kadu does not support user profiles.&lt;br /&gt;Instead, multiple account are supported in one instances of kadu.&lt;/p&gt;&lt;p&gt;Please select profiles that you would like to import as&lt;br /&gt;account into this instance of Kadu.&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Profile %1 successfully imported!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import profile...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to import profile: %1: %2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ProfileImporter</name>
    <message>
        <source>Unable to open profile file [%1].</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account already exists.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Imported account has no ID</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ProfilesImportActions</name>
    <message>
        <source>Import profiles...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/profiles_import/translations/profiles_import_szl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="szl">
<context>
    <name>ImportProfileWindow</name>
    <message>
        <source>Import external Kadu 0.6.5 profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select profile path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select profile path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select imported account identity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Identity not selected&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Selected directory does not contain kadu.conf.xml file&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory is not a Kadu profile directory.
File kadu.conf.xml not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Profile successfully imported!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to import profile: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportProfilesWindow</name>
    <message>
        <source>&lt;p&gt;Current version of Kadu does not support user profiles.&lt;br /&gt;Instead, multiple account are supported in one instances of kadu.&lt;/p&gt;&lt;p&gt;Please select profiles that you would like to import as&lt;br /&gt;account into this instance of Kadu.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Profile %1 successfully imported!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import profile...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to import profile: %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfileImporter</name>
    <message>
        <source>Unable to open profile file [%1].</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account already exists.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported account has no ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfilesImportActions</name>
    <message>
        <source>Import profiles...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
